@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import re
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, ClassVar, Iterable, cast
+from typing import TYPE_CHECKING, ClassVar, Iterable
 
 from rich.cells import cell_len, get_character_cell_size
 from rich.console import Console, ConsoleOptions, RenderableType
@@ -12,32 +12,31 @@ from rich.segment import Segment
 from rich.text import Text
 from typing_extensions import Literal
 
-from .. import events
-from .._segment_tools import line_crop
+from textual import events
+from textual._segment_tools import line_crop
 
 if TYPE_CHECKING:
-    from ..app import RenderResult
+    from textual.app import RenderResult
 
-from ..binding import Binding, BindingType
-from ..css._error_tools import friendly_list
-from ..events import Blur, Focus, Mount
-from ..geometry import Offset, Size
-from ..message import Message
-from ..reactive import Reactive, reactive, var
-from ..suggester import Suggester, SuggestionReady
-from ..timer import Timer
-from ..validation import ValidationResult, Validator
-from ..widget import Widget
+from textual.binding import Binding, BindingType
+from textual.css._error_tools import friendly_list
+from textual.events import Blur, Focus, Mount
+from textual.geometry import Offset, Size
+from textual.message import Message
+from textual.reactive import Reactive, reactive, var
+from textual.suggester import Suggester, SuggestionReady
+from textual.timer import Timer
+from textual.validation import ValidationResult, Validator
+from textual.widget import Widget
 
 InputValidationOn = Literal["blur", "changed", "submitted"]
 """Possible messages that trigger input validation."""
 _POSSIBLE_VALIDATE_ON_VALUES = {"blur", "changed", "submitted"}
 """Set literal with the legal values for the type `InputValidationOn`."""
 
-
 _RESTRICT_TYPES = {
-    "integer": r"[-+]?\d*",
-    "number": r"[-+]?\d*\.?\d*[eE]?[-+]?\d*",
+    "integer": r"[-+]?(?:\d*|\d+_)*",
+    "number": r"[-+]?(?:\d*|\d+_)*\.?(?:\d*|\d+_)*(?:\d[eE]?[-+]?(?:\d*|\d+_)*)?",
     "text": None,
 }
 InputType = Literal["integer", "number", "text"]
@@ -151,24 +150,51 @@ class Input(Widget, can_focus=True):
         border: tall $background;
         width: 100%;
         height: 3;
+
+        &:focus {
+            border: tall $accent;
+        }
+        &>.input--cursor {
+            background: $surface;
+            color: $text;
+            text-style: reverse;
+        }
+        &>.input--placeholder, &>.input--suggestion {
+            color: $text-disabled;
+        }
+        &.-invalid {
+            border: tall $error 60%;
+        }
+        &.-invalid:focus {
+            border: tall $error;
+        }    
+
+        &.-ansi-colors {
+            background: ansi_default;
+            color: ansi_default;
+            border: tall ansi_default;
+
+            &:focus {
+                border: tall ansi_blue;
+            }
+            &>.input--cursor {     
+                background: ansi_default;           
+                text-style: reverse;
+            }
+            &>.input--placeholder, &>.input--suggestion {
+                text-style: dim;
+                color: ansi_default;
+            }
+            &.-invalid {
+                border: tall ansi_red;
+            }
+            &.-invalid:focus {
+                border: tall ansi_red;
+            }  
+            
+        }
     }
-    Input:focus {
-        border: tall $accent;
-    }
-    Input>.input--cursor {
-        background: $surface;
-        color: $text;
-        text-style: reverse;
-    }
-    Input>.input--placeholder, Input>.input--suggestion {
-        color: $text-disabled;
-    }
-    Input.-invalid {
-        border: tall $error 60%;
-    }
-    Input.-invalid:focus {
-        border: tall $error;
-    }
+
     """
 
     cursor_blink = reactive(True, init=False)
@@ -301,7 +327,7 @@ class Input(Widget, can_focus=True):
             self.validators = list(validators)
 
         self.validate_on: set[str] = (
-            (_POSSIBLE_VALIDATE_ON_VALUES & cast("set[str]", validate_on))
+            (_POSSIBLE_VALIDATE_ON_VALUES & set(validate_on))
             if validate_on is not None
             else _POSSIBLE_VALIDATE_ON_VALUES
         )
@@ -328,7 +354,7 @@ class Input(Widget, can_focus=True):
         self.type = type
         self.max_length = max_length
         if not self.validators:
-            from ..validation import Integer, Number
+            from textual.validation import Integer, Number
 
             if self.type == "integer":
                 self.validators.append(Integer())
@@ -361,6 +387,20 @@ class Input(Widget, can_focus=True):
         """Flag to indicate if the cursor is at the end"""
         return self.cursor_position >= len(self.value)
 
+    def check_consume_key(self, key: str, character: str | None) -> bool:
+        """Check if the widget may consume the given key.
+
+        As an input we are expecting to capture printable keys.
+
+        Args:
+            key: A key identifier.
+            character: A character associated with the key, or `None` if there isn't one.
+
+        Returns:
+            `True` if the widget may capture the key in it's `Key` message, or `False` if it won't.
+        """
+        return character is not None and character.isprintable()
+
     def validate_cursor_position(self, cursor_position: int) -> int:
         return min(max(0, cursor_position), len(self.value))
 
@@ -583,7 +623,7 @@ class Input(Widget, can_focus=True):
     def _pause_blink_cycle(self) -> None:
         """Hide the blinking cursor and pause the blink cycle."""
         self._cursor_visible = False
-        if self.cursor_blink and self._blink_timer:
+        if self._blink_timer:
             self._blink_timer.pause()
 
     def insert_text_at_cursor(self, text: str) -> None:
