@@ -9,15 +9,15 @@ from rich.padding import Padding
 from rich.rule import Rule
 from rich.style import NULL_STYLE, Style
 
-from .. import _widget_navigation, events
-from .._widget_navigation import Direction
-from ..binding import Binding, BindingType
-from ..cache import LRUCache
-from ..geometry import Region, Size
-from ..message import Message
-from ..reactive import reactive
-from ..scroll_view import ScrollView
-from ..strip import Strip
+from textual import _widget_navigation, events
+from textual._widget_navigation import Direction
+from textual.binding import Binding, BindingType
+from textual.cache import LRUCache
+from textual.geometry import Region, Size
+from textual.message import Message
+from textual.reactive import reactive
+from textual.scroll_view import ScrollView
+from textual.strip import Strip
 
 if TYPE_CHECKING:
     from typing_extensions import Self, TypeAlias
@@ -398,6 +398,20 @@ class OptionList(ScrollView, can_focus=True):
             for option in self._options
         )
 
+    def get_content_height(self, container: Size, viewport: Size, width: int) -> int:
+        # Get the content height without requiring a refresh
+        # TODO: Internal data structure could be simplified
+        style = self.rich_style
+        _render_option_content = self._render_option_content
+        heights = [
+            len(_render_option_content(index, option, style, width))
+            for index, option in enumerate(self._options)
+        ]
+        separator_count = sum(
+            1 for content in self._contents if isinstance(content, Separator)
+        )
+        return sum(heights) + separator_count
+
     def _on_mouse_move(self, event: events.MouseMove) -> None:
         """React to the mouse moving.
 
